## Mass-Partnering for Software Development and Maintenance

The use of free and open source software has always been at the core of the F123 strategy to achieve as much as possible with scarce resources. The greatest advantage of open source is not its short-term pricing advantage, but its licensing structure and community of developers, which makes it possible to achieve [massive and widespread cooperation](https://thenewstack.io/contributes-linux-kernel/) without the need for specific partnership contracts between all organizations or individuals. Even [industry leaders who have traditionally attempted to undermine advancements in the adoption of the open source development model](https://www.extremetech.com/computing/239616-hell-freezes-microsoft-joins-linux-foundation), have changed their approach to working with this large segment of the software world.

In the context of digital accessibility for the blind, there is already [ample evidence](http://community.nvda-project.org/usersByCountry.html) of the widespread use of free and open source software. F123 [supports projects such as NVDA](https://duckduckgo.com/?q=NVDA+conference+F123.access&t=ffsb&atb=v53-1&ia=web), yet, the F123Light initiative seeks to address a different set of needs among the blind who live in developing countries.

### Cost Revisited

While an initiative such as the free and open source [NVDA screen reader](https://www.nvaccess.org/) is extremely valuable, the F123 team is pushing the envelope of what is possible to accomplish with [ultra-low-cost computers](https://www.raspberrypi.org/). NVDA enables blind persons to save thousands of dollars, as they are no longer forced to buy expensive traditional proprietary screen readers such as Jaws for Windows, but it still requires them to absorb the cost of the Windows operating system, hardware which is powerful enough to run it, and related costs such as antivirus software. In other words, the blind are still forced to deal with and find funding for the [planned obsolescence strategy](https://www.gaia.com/article/how-is-planned-obsolescence-harmful-to-the-environment) of various companies, in addition to the natural wear and tear of hardware and overall technological change.

Our choice of computers based on ARM processors such as the Raspberry Pi stems from the fact that they tend to be dramatically more affordable and still offer sufficient computing performance given our needs and design choices. Specifically, despite the fact that we are using an extremely affordable computer, our device boots-up faster than most conventional laptops and still allows our users to be productive and competitive in their use of e-mail, text editors, spreadsheets, and web browsers. In this regard, our most interesting decision was to emphasize text-based interfaces over the traditional [graphical user interface](https://en.wikipedia.org/wiki/Graphical_user_interface) (GUI).

Graphical interfaces tend to demand a lot of computing power for visual effects that are entirely irrelevant for the blind. In fact, the only advantage of GUI's for the blind is the use of menus, which present the user with multiple choices instead of requiring that he or she type complicated-sounding commands on the command line interface (CLI). However, [there are text-based menus](http://joeyh.name/code/pdmenu/) which allow us to make our text-based environment as friendly or more friendly than any graphical interface we have ever tested.

## Software Choices and Universal Design Considerations

In a perfect world, all software companies would adopt "[universal design](https://en.wikipedia.org/wiki/Universal_design)" principles, and other than our need for more efficient and fast computing, there would be no need for us to work with text-only menus. However, both in desktop and web interfaces, the blind are not a priority, even for the most powerful and resource-rich companies. This [was the case in the 1990's](https://nfb.org/images/nfb/publications/bm/bm99/bm991201.htm) and is still the case on the 21st century, even in companies which are [supposed to be the gold standard in accessibility](https://www.marcozehe.de/2015/01/06/apple-are-losing-their-edge-also-in-accessibility-quality/).

Many organizations and companies claim that they do not have the resources or expertise to offer fully accessible software or web pages, but if even the most successful companies fail to deliver consistently accessible products, lack of resources seems to be at the very least, an insufficient explanation. At other times it is claimed that legislation should be better, but it is impossible to correctly regulate technologies which have not yet emerged, and dangerous to establish too many restrictions for companies which then may lose their leadership in the marketplace to foreign competitors without such concerns. This probably explains why many large companies seem to launch accessibility campaigns only after they have established themselves as leaders in their industry and need to look for expansion in what they consider niche markets, in order to try to sustain growth.

In our view, the blind, their friends, and their organizations must keep their pressure and advocacy efforts to ensure continued progress (or at least prevent regression), but we do not expect such efforts to, on average, be more powerful than the competitive pressures companies face every day nor the influence from so many groups which governments also must respond to. In other words, the overall patterns observed in the last 30+ years are likely to persist and the blind community better have a "plan B" for its most basic computing needs, if it wants consistent, productive, affordable, stable, long-term digital accessibility.

## Software at the Core of Our Strategy

Since our team does not have any truly innovative means to pressure for new and more effective legislation nor better compliance with existing accessibility laws, we will focus our energies and creativity on ensuring that basic computing functionality will always be affordable, effective, and efficient for our community. The objective is not to find a perfect solution nor break new ground in artificial intelligence or any other fashionable area, but to utilize that which is proven, accessible for decades, and ensure that non-technical persons also have the luxury of resilience in the face of ever changing priorities and fads among industry leaders and governments.

